@@ -10,7 +10,6 @@
 #include <vector>
 #include <iostream>
 #include <algorithm>
-#include <assert.h>
 #include <math.h>
 #include <climits>
 
@@ -18,9 +17,9 @@
 
 using namespace std;
 
-vector< vector<double > > Find_Grid(Cluster &clusters, int min_bin_limit = 2);
+vector< vector<double > > Find_Grid(Cluster &clusters, vector<int> min_bin_limit);
 
-vector<double> Find_1D_Grid(Cluster &clusters, int dim, int min_bin_limit);
+vector<double> Find_1D_Grid(Cluster &clusters, int dim, vector<int> min_bin_limit);
 
 vector<vector<double> > prep_index(vector<double> &c1, vector<double> &c2, double middle_1, double middle_2);
 
